from simplenlp import DefaultNL

def NL():
    return DefaultNL()

